#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AssemblyConstraintSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AsmConstraintSettingAtt
                | 
                | Represents the Assembly Constraints setting controller object.
                | Role: the Assembly Constraints setting controller object deals with the setting
                | parameters displayed in the Assembly Constraints property page. To access this
                | property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of Mechanical Design to unfold the workbench
                |     list
                |     Click Assembly Design: Constraints tab
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_constraint_setting_att = com_object

    @property
    def constraint_creation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConstraintCreationMode() As
                | CatAsmConstraintCreationMode
                | 
                |     Returns or sets the constraint creation setting parameter.
                |     Role: The constraint creation setting parameter manages the determination
                |     of the kind of elements to constraint.
                |     Legal values:
                |     catUseAnyGeometry The constraint can be created on any kind of
                |     geometry
                |     catUsePublishedGeometryChildLevel The constraint can only be created on
                |     geometry published on the direct child level
                |     catUsePublishedGeometryAnyLevel The constraint can only be created on
                |     geometry published on any assembly level
                | 
                |     Example:
                |         The following example retrieves the constraint creation setting
                |         parameter of AsmConstraintSettingAtt1 in CreationMode and sets the mode to
                |         catUsePublishedGeometryAnyLevel.
                | 
                |          Set CreationMode = AsmConstraintSettingAtt1.ConstraintCreationMode
                |          AsmConstraintSettingAtt1.ConstraintCreationMode = catUsePublishedGeometryAnyLevel

        :return: enum cat_asm_constraint_creation_mode
        :rtype: int
        """

        return self.assembly_constraint_setting_att.ConstraintCreationMode

    @constraint_creation_mode.setter
    def constraint_creation_mode(self, value: int):
        """
        :param int value: enum cat_asm_constraint_creation_mode
        """

        self.assembly_constraint_setting_att.ConstraintCreationMode = value

    @property
    def paste_component_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PasteComponentMode() As CatAsmPasteComponentMode
                | 
                |     Returns or sets the component paste setting parameter.
                |     Role: The component paste setting parameter manages the keeping of the
                |     contraints of a component after a Copy/Paste or a
                |     Cut/Paste.
                |     Legal values:
                |     catPasteWithoutCsts The component's constraints will not be
                |     recreated
                |     catPasteWithCstOnCopy The component's constraints will only be recreated
                |     after a Copy
                |     catPasteWithCstOnCut The component's constraints will only be recreated
                |     after a Cut
                |     catPasteWithCstOnCopyAndCut The component's constraints will be recreated
                |     after a Copy or a Cut
                | 
                |     Example:
                |         The following example retrieves the component paste setting parameter
                |         of AsmConstraintSettingAtt1 in PasteMode and sets the mode to With Cut
                |         Only.
                | 
                |          Set PasteMode = AsmConstraintSettingAtt1.PasteComponentMode
                |          AsmConstraintSettingAtt1.PasteComponentMode = catPasteWithCstOnCut

        :return: enum cat_asm_paste_component_mode
        :rtype: int
        """

        return self.assembly_constraint_setting_att.PasteComponentMode

    @paste_component_mode.setter
    def paste_component_mode(self, value: int):
        """
        :param int value: enum cat_asm_paste_component_mode
        """

        self.assembly_constraint_setting_att.PasteComponentMode = value

    @property
    def quick_constraint_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property QuickConstraintMode() As CatAsmQuickConstraintMode
                | 
                |     Returns or sets the quick constraint setting parameter.
                |     Role: The quick constraint setting parameter manages the type of contraint
                |     that will be created by tue Quick Constraint command.
                |     Legal values:
                |     catSpecifiedOrder Use the specified order
                |     catVerifiedConstraintFirst Create verified constraint
                |     first
                | 
                |     Example:
                |         The following example retrieves the quick constraint setting parameter
                |         of AsmConstraintSettingAtt1 in QuickMode and sets the mode to
                |         catSpecifiedOrder.
                | 
                |          Set QuickMode = AsmConstraintSettingAtt1.QuickConstraintMode
                |          AsmConstraintSettingAtt1.QuickConstraintMode = catSpecifiedOrder

        :return: enum cat_asm_quick_constraint_mode
        :rtype: int
        """

        return self.assembly_constraint_setting_att.QuickConstraintMode

    @quick_constraint_mode.setter
    def quick_constraint_mode(self, value: int):
        """
        :param int value: enum cat_asm_quick_constraint_mode
        """

        self.assembly_constraint_setting_att.QuickConstraintMode = value

    @property
    def redundancy_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RedundancyMode(CatAsmRedundancyMode
                | iRedundancyMode)
                | 
                |     Sets redundancy check option for constraint creation.
                |     Role: The Redundancy of the constraint is decided to be checked or not to
                |     be checked, for constraint creation.
                |     Legal values:
                |     catUnChecked Redundancy of constraint will be checked while constraint
                |     creation.
                |     catChecked Redundancy of constraint will not be checked while constraint
                |     creation.

        :return: enum cat_asm_redundancy_mode
        :rtype: int
        """

        return self.assembly_constraint_setting_att.RedundancyMode

    @redundancy_mode.setter
    def redundancy_mode(self, value: int):
        """
        :param int value: enum cat_asm_redundancy_mode
        """

        self.assembly_constraint_setting_att.RedundancyMode = value

    def get_constraint_creation_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConstraintCreationModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves informations about the constraint creation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.assembly_constraint_setting_att.GetConstraintCreationModeInfo(io_admin_level, io_locked)

    def get_paste_component_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPasteComponentModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves informations about the component paste setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.assembly_constraint_setting_att.GetPasteComponentModeInfo(io_admin_level, io_locked)

    def get_quick_constraint_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetQuickConstraintModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves informations about the quick constraint setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.assembly_constraint_setting_att.GetQuickConstraintModeInfo(io_admin_level, io_locked)

    def get_quick_constraint_ordered_list(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetQuickConstraintOrderedList() As CATSafeArrayVariant
                | 
                |     Returns the quick constraint ordered list setting
                |     parameter.
                |     Role: The quick constraint ordered list setting parameter manages the
                |     determination of the kind of elements to constraint.
                | 
                |     Parameters:
                | 
                |         ioList
                |             The ordered list of constraints type The constraints types must be
                |             precise strings 
                | 
                |     Example:
                |         The following example retrieves the quick constraint ordered list of
                |         AsmConstraintSettingAtt1 in QuickList
                | 
                |          Dim QuickList
                |          QuickList = AsmConstraintSettingAtt1.GetQuickConstraintOrderedList()

        :rtype: tuple
        """
        return self.assembly_constraint_setting_att.GetQuickConstraintOrderedList()

    def set_constraint_creation_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConstraintCreationModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the constraint creation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_constraint_setting_att.SetConstraintCreationModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_constraint_creation_mode_lock'
        # # vba_code = """
        # # Public Function set_constraint_creation_mode_lock(asm_constraint_setting_att)
        # #     Dim iLocked (2)
        # #     asm_constraint_setting_att.SetConstraintCreationModeLock iLocked
        # #     set_constraint_creation_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_paste_component_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPasteComponentModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the component paste setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_constraint_setting_att.SetPasteComponentModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_paste_component_mode_lock'
        # # vba_code = """
        # # Public Function set_paste_component_mode_lock(asm_constraint_setting_att)
        # #     Dim iLocked (2)
        # #     asm_constraint_setting_att.SetPasteComponentModeLock iLocked
        # #     set_paste_component_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_quick_constraint_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetQuickConstraintModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the quick constraint setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_constraint_setting_att.SetQuickConstraintModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_quick_constraint_mode_lock'
        # # vba_code = """
        # # Public Function set_quick_constraint_mode_lock(asm_constraint_setting_att)
        # #     Dim iLocked (2)
        # #     asm_constraint_setting_att.SetQuickConstraintModeLock iLocked
        # #     set_quick_constraint_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_quick_constraint_ordered_list(self, i_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetQuickConstraintOrderedList(CATSafeArrayVariant
                | iList)
                | 
                |     Sets the quick constraint ordered list setting parameter.
                |     Role: The quick constraint ordered list setting parameter manages the
                |     determination of the kind of elements to constraint.
                | 
                |     Parameters:
                | 
                |         iList
                |             The ordered list of constraints type The constraints types must be
                |             precise strings 
                | 
                |     Example:
                |         The following example sets the quick constraint ordered list of
                |         AsmConstraintSettingAtt1
                | 
                |          Dim QuickList(5)
                |          QuickList(0) = "CATAsmCoincidenceType"
                |          QuickList(1) = "CATAsmSurfContactType"
                |          QuickList(2) = "CATAsmAngleType"
                |          QuickList(3) = "CATAsmDistanceType"
                |          QuickList(4) = "CATAsmPerpendType"
                |          QuickList(5) = "CATAsmParallelType"
                |          AsmConstraintSettingAtt1.SetQuickConstraintOrderedListQuickList

        :param tuple i_list:
        :rtype: None
        """
        return self.assembly_constraint_setting_att.SetQuickConstraintOrderedList(i_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_quick_constraint_ordered_list'
        # # vba_code = """
        # # Public Function set_quick_constraint_ordered_list(asm_constraint_setting_att)
        # #     Dim iList (2)
        # #     asm_constraint_setting_att.SetQuickConstraintOrderedList iList
        # #     set_quick_constraint_ordered_list = iList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyConstraintSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_nodes import ArrangementNodes
from pycatia.system_interfaces.any_object import AnyObject


class ArrangementBoundary(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementBoundary
                | 
                | Access properties and functions of an ArrangementBoundary
                | object.
                | Role: Use this interface to control the visualization mode, section parameters,
                | nodes that define the ArrangementBoundary object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_boundary = com_object

    @property
    def arrangement_nodes(self) -> ArrangementNodes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementNodes() As ArrangementNodes (Read Only)
                | 
                |     Returns the collection of ArrangementNodes that make up the
                |     ArrangementBoundary.
                | 
                |     Example:
                |         This example gets the ArrangementNodes for the objBoundary1
                |         object.
                | 
                |          Dim objArrNodes   As ArrangementNodes
                |          Set objArrNodes = objBoundary1.ArrangementNodes

        :rtype: ArrangementNodes
        """

        return ArrangementNodes(self.arrangement_boundary.ArrangementNodes)

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double (Read Only)
                | 
                |     Returns the length of the ArrangementBoundary object.
                | 
                |     Example:
                |         This example retrieves the Length of the objBoundary1
                |         object.
                | 
                |          Dim dblBoundaryLength   As Double
                |          dblBoundaryLength  = objBoundary1.Length

        :rtype: float
        """

        return self.arrangement_boundary.Length

    @property
    def section_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionHeight() As double
                | 
                |     Returns or sets the SectionHeight for an ArrangementBoundary
                |     object.
                | 
                |     Example:
                |         This example gets the SectionHeight for the objBoundary1
                |         object.
                | 
                |          Dim dblSectionHeight   As Double
                |          dblSectionHeight = objBoundary1.SectionHeight

        :rtype: float
        """

        return self.arrangement_boundary.SectionHeight

    @section_height.setter
    def section_height(self, value: float):
        """
        :param float value:
        """

        self.arrangement_boundary.SectionHeight = value

    @property
    def section_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionType() As CATArrangementRouteSection
                | 
                |     Returns or sets the SectionType for an ArrangementBoundary
                |     object.
                |     Legal values:
                | 
                |     CatArrangementRouteSectionNone
                |     CatArrangementRouteSectionRectangular
                | 
                |     Example:
                |         This example sets the SectionType for the objBoundary1 object to
                |         CatArrangementRouteSectionRectangular.
                | 
                |          objBoundary1.SectionType = CatArrangementRouteSectionRectangular

        :return: enum cat_arrangement_route_section
        :rtype: int
        """

        return self.arrangement_boundary.SectionType

    @section_type.setter
    def section_type(self, value: int):
        """
        :param int value: enum cat_arrangement_route_section
        """

        self.arrangement_boundary.SectionType = value

    @property
    def section_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionWidth() As double
                | 
                |     Returns or sets the SectionWidth for an ArrangementBoundary
                |     object.
                | 
                |     Example:
                |         This example gets the SectionWidth for the objBoundary1
                |         object.
                | 
                |          Dim dblSectionWidth   As Double
                |          dblSectionWidth = objBoundary1.SectionWidth

        :rtype: float
        """

        return self.arrangement_boundary.SectionWidth

    @section_width.setter
    def section_width(self, value: float):
        """
        :param float value:
        """

        self.arrangement_boundary.SectionWidth = value

    @property
    def visu_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuMode() As CATArrangementRouteVisuMode
                | 
                |     Returns or sets the Visualization Mode for an ArrangementBoundary
                |     object.
                | 
                |     Example:
                |         This example sets the Visualization Mode for the objBoundary1 object to
                |         CatArrangementRouteVisuModeSolid.
                | 
                |          objBoundary1.VisuMode = CatArrangementRouteVisuModeSolid

        :return: enum cat_arrangement_route_visu_mode
        :rtype: int
        """

        return self.arrangement_boundary.VisuMode

    @visu_mode.setter
    def visu_mode(self, value: int):
        """
        :param int value: enum cat_arrangement_route_visu_mode
        """

        self.arrangement_boundary.VisuMode = value

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the applicative data whose type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                |         oApplicativeObj
                |             The matched applicative object.
                | 
                |             Example:
                |                 This example retrieves the desired applicative object from the
                |                 objBoundary1 object.
                | 
                |                  Dim objProd   As Product
                |                  objProd  = objBoundary1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_boundary.GetTechnologicalObject(i_application_type)

    def __repr__(self):
        return f'ArrangementBoundary(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity


class HumanActivityGroup(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             HumanActivityGroup
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIAHumanActivityGroup are
                | ...
                | 
                | Do not use the DNBIAHumanActivityGroup interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_activity_group = com_object

    @property
    def motion_basis(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MotionBasis() As HTSActivityGroupMotionBasis
                | 
                |     Returns or Sets Motion-Basis (see HTSActivityGroupMotionBasis for list of
                |     possible values)

        :return: enum hts_activity_group_motion_basis
        :rtype: int
        """

        return self.human_activity_group.MotionBasis

    @motion_basis.setter
    def motion_basis(self, value: int):
        """
        :param int value: enum hts_activity_group_motion_basis
        """

        self.human_activity_group.MotionBasis = value

    @property
    def reference_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceTime() As double
                | 
                |     Returns or Sets ReferenceTime for HumanActivityGroup Activity

        :rtype: float
        """

        return self.human_activity_group.ReferenceTime

    @reference_time.setter
    def reference_time(self, value: float):
        """
        :param float value:
        """

        self.human_activity_group.ReferenceTime = value

    @property
    def user_speed(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserSpeed() As double
                | 
                |     Returns or Sets Speed for HumanActivityGroup Activity

        :rtype: float
        """

        return self.human_activity_group.UserSpeed

    @user_speed.setter
    def user_speed(self, value: float):
        """
        :param float value:
        """

        self.human_activity_group.UserSpeed = value

    @property
    def user_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserTime() As double
                | 
                |     Returns or Sets Time for HumanActivityGroup Activity

        :rtype: float
        """

        return self.human_activity_group.UserTime

    @user_time.setter
    def user_time(self, value: float):
        """
        :param float value:
        """

        self.human_activity_group.UserTime = value

    def __repr__(self):
        return f'HumanActivityGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_comp_group_ext import SchCompGroupExt
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.system_interfaces.any_object import AnyObject


class SchCatalogComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCatalogComponent
                | 
                | Manage a schematic component catalog.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_catalog_component = com_object

    def query_drop_ability(self, o_b_yes: bool) -> SchGRRComp:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func QueryDropAbility(boolean oBYes) As SchGRRComp
                | 
                |     Check to see if it is OK to be dropped to the current
                |     document.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to be dropped. 
                |         oPointedToComp
                |             Graphical representation of a component pointed-to by the catalog
                |             description 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCatalogComponent
                |          Dim bVar1 As boolean
                |          Dim objArg2 As SchGRRComp
                |           ...
                |          Set objArg2 = objThisIntf.QueryDropAbility

        :param bool o_b_yes:
        :rtype: SchGRRComp
        """
        return SchGRRComp(self.sch_catalog_component.QueryDropAbility(o_b_yes))

    def query_drop_comp_group_ability(self, o_b_yes: bool) -> SchCompGroupExt:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func QueryDropCompGroupAbility(boolean oBYes) As
                | SchCompGroupExt
                | 
                |     Check to see if it is OK to be dropped a component group to the current
                |     document.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to be dropped. 
                |         oPointedToGroup
                |             Component group extension pointed-to by the catalog description
                |
                |     Example:
                |
                |          Dim objThisIntf As SchCatalogComponent
                |          Dim bVar1 As boolean
                |          Dim objArg2 As SchCompGroupExt
                |           ...
                |          Set objArg2 = objThisIntf.QueryDropCompGroupAbility

        :param bool o_b_yes:
        :rtype: SchCompGroupExt
        """
        return SchCompGroupExt(self.sch_catalog_component.QueryDropCompGroupAbility(o_b_yes))

    def __repr__(self):
        return f'SchCatalogComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.navigator_interfaces.annotated_view import AnnotatedView
from pycatia.navigator_interfaces.annotated_views import AnnotatedViews
from pycatia.navigator_interfaces.dmu_data_flow import DMUDataFlow
from pycatia.navigator_interfaces.groups import Groups
from pycatia.navigator_interfaces.hyperlinks import Hyperlinks
from pycatia.navigator_interfaces.marker_3Ds import Marker3Ds
from pycatia.system_interfaces.any_object import AnyObject


class NavigatorWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         NavigatorWorkbench
                | 
                | The object to manage all DMU Navigator entities.
                | 
                | This version allows to manage groups and annotated views.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.navigator_workbench = com_object

    @property
    def annotated_views(self) -> AnnotatedViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnnotatedViews() As AnnotatedViews (Read Only)
                | 
                |     Returns the AnnotatedViews collection.
                | 
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("AnnotatedViews") on the
                |     root product, to retrieve the AnnotatedViews collection.
                | 
                |     Example:
                | 
                |              This example retrieves the AnnotatedViews collection of the active
                |              document.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             Dim TheAnnotatedViewsList As AnnotatedViews
                |             Set TheAnnotatedViewsList = TheNavigatorWorkbench.AnnotatedViews

        :rtype: AnnotatedViews
        """

        return AnnotatedViews(self.navigator_workbench.AnnotatedViews)

    @property
    def dmu_data_flow(self) -> DMUDataFlow:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DMUDataFlow() As DMUDataFlow (Read Only)
                | 
                |     Returns the DMU DataFlow object.

        :rtype: DMUDataFlow
        """

        return DMUDataFlow(self.navigator_workbench.DMUDataFlow)

    @property
    def groups(self) -> Groups:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Groups() As Groups (Read Only)
                | 
                |     Returns the Groups collection.
                | 
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Groups") on the root
                |     product, to retrieve the Groups collection.
                | 
                |     Example:
                | 
                |              This example retrieves the Groups collection of the active
                |              document.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             Dim TheGroupsList As Groups
                |             Set TheGroupsList = TheNavigatorWorkbench.Groups

        :rtype: Groups
        """

        return Groups(self.navigator_workbench.Groups)

    @property
    def hyperlinks(self) -> Hyperlinks:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Hyperlinks() As Hyperlinks (Read Only)
                | 
                |     Returns the Hyperlinks collection.
                | 
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Hyperlinks") on the root
                |     product, to retrieve the Hyperlinks collection.
                | 
                |     Example:
                | 
                |              This example retrieves the Hyperlinks collection of the active
                |              document.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             Dim HyperlinksList As Hyperlinks
                |             Set HyperlinksList = TheNavigatorWorkbench.Hyperlinks

        :rtype: Hyperlinks
        """

        return Hyperlinks(self.navigator_workbench.Hyperlinks)

    @property
    def marker3_ds(self) -> Marker3Ds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker3Ds() As Marker3Ds (Read Only)
                | 
                |     Returns the Marker3Ds collection.
                | 
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Marker3Ds") on the root
                |     product, to retrieve the Marker3Ds collection.
                | 
                |     Example:
                | 
                |              This example retrieves the Marker3Ds collection of the active
                |              document.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             Dim TheMarker3DsList As AnnotatedViews
                |             Set TheMarker3DsList = TheNavigatorWorkbench.Marker3Ds

        :rtype: Marker3Ds
        """

        return Marker3Ds(self.navigator_workbench.Marker3Ds)

    def advanced_view(self, i_annotated_view: AnnotatedView, i_view_option: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AdvancedView(AnnotatedView iAnnotatedView,
                | short iViewOption)
                | 
                |     Applies the annotated view to the current viewer.
                | 
                |     Parameters:
                | 
                |         iAnnotatedView
                |             The annotated view to apply. 
                |         iViewOptions
                |             The option to launch the annotated view command, possible values
                |             are
                | 
                |                 CatAnnotatedViewCmdOption_NoToolbar : No Toolbar for annotation creation
                |                 CatAnnotatedViewCmdOption_NoAnimation : No Animation when applying the view 
                | 
                |     Example:
                | 
                |              This example applies the view of the NewAnnotatedView
                |              AnnotatedView.
                |             
                |              TheNavigatorWorkbench.View,
                |              CatAnnotatedViewCmdOption_NoAnimation+CatAnnotatedViewCmdOption_NoToolbar(
                |              NewAnnotatedView)


        :param AnnotatedView i_annotated_view:
        :param int i_view_option:
        :rtype: None
        """
        return self.navigator_workbench.AdvancedView(i_annotated_view.com_object, i_view_option)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'advanced_view'
        # # vba_code = """
        # # Public Function advanced_view(navigator_workbench)
        # #     Dim iAnnotatedView (2)
        # #     navigator_workbench.AdvancedView iAnnotatedView
        # #     advanced_view = iAnnotatedView
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_order(self, i_object: AnyObject) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOrder(CATBaseDispatch iObject) As long
                | 
                |     Returns the order of an object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object whose rank has to be returned. 
                |         oCurrentRank
                |             The current rank of the object (from 1 to n the number of objects
                |             in the collection). 
                | 
                |     Example:
                | 
                |              This example creates an annotated view NewAnnotatedView and
                |              returns its position.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             
                |             Dim NewAnnotatedView As AnnotatedView
                |             Set NewAnnotatedView = TheAnnotatedViews.Add
                |             
                |             Dim iOrder As Integer
                |             iOrder = TheNavigatorWorkbench.GetOrder(NewAnnotatedView)

        :param AnyObject i_object:
        :rtype: int
        """
        return self.navigator_workbench.GetOrder(i_object.com_object)

    def set_order(self, i_object: AnyObject, i_new_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOrder(CATBaseDispatch iObject,
                | long iNewRank)
                | 
                |     Sets the order of an object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object whose rank has to be modified. 
                |         iNewRank
                |             The new rank of the object (from 1 to n the number of objects in
                |             the collection). 
                | 
                |     Example:
                | 
                |              This example creates an annotated view NewAnnotatedView and move
                |              it to the first position.
                |             
                | 
                |             Dim TheNavigatorWorkbench As Workbench
                |             Set TheNavigatorWorkbench = CATIA.ActiveDocument.GetWorkbench ( "NavigatorWorkbench" )
                |             
                |             Dim NewAnnotatedView As AnnotatedView
                |             Set NewAnnotatedView = TheAnnotatedViews.Add
                |             TheNavigatorWorkbench.SetOrder NewAnnotatedView, 1

        :param AnyObject i_object:
        :param int i_new_rank:
        :rtype: None
        """
        return self.navigator_workbench.SetOrder(i_object.com_object, i_new_rank)

    def view(self, i_annotated_view: AnnotatedView) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub View(AnnotatedView iAnnotatedView)
                | 
                |     Applies the annotated view to the current viewer.
                | 
                |     Parameters:
                | 
                |         iAnnotatedView
                |             The annotated view to apply. 
                | 
                |     Example:
                | 
                |              This example applies the view of the NewAnnotatedView
                |              AnnotatedView.
                |             
                | 
                |             TheNavigatorWorkbench.View(NewAnnotatedView)

        :param AnnotatedView i_annotated_view:
        :rtype: None
        """
        return self.navigator_workbench.View(i_annotated_view.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'view'
        # # vba_code = """
        # # Public Function view(navigator_workbench)
        # #     Dim iAnnotatedView (2)
        # #     navigator_workbench.View iAnnotatedView
        # #     view = iAnnotatedView
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'NavigatorWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMReferences(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmReferences
                | 
                | A Collection of U and V Reference elements for Standard
                | Opening.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Reference)
        self.sfm_references = com_object

    def add(self, i_reference: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add(Reference iReference)
                | 
                |     Adds a reference in the collection.
                | 
                |     Parameters:
                | 
                |         iReference
                |             [in] Reference. 
                | 
                |     Returns:
                |         S_OK if everything ran ok. 
                |         This example Adds one U Reference to the list of
                |         SfmReferences.
                | 
                |          Dim Uref1 As Reference
                |          Set Uref1 = Part1.FindObjectByName("CROSS.95")
                |          'Add one U Reference to the list
                |          Dim UrefList As SfmReferences
                |           UrefList.Add Uref1

        :param Reference i_reference:
        :rtype: None
        """
        return self.sfm_references.Add(i_reference.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add'
        # # vba_code = """
        # # Public Function add(sfm_references)
        # #     Dim iReference (2)
        # #     sfm_references.Add iReference
        # #     add = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def clear_list(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearList()
                | 
                |     Clears the contents of existing list of SfmReferences.
                | 
                |     Returns:
                |         Error code
                | 
                |         Example:
                |             This example clears the contents of a list.
                | 
                |               Dim ListofRef As SfmReferences
                |               Dim Uref1 as Reference
                |               ListofRef.Add Uref1
                |               ListofRef.ClearList

        :rtype: None
        """
        return self.sfm_references.ClearList()

    def item(self, i_index: cat_variant) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Reference
                | 
                |     Retrieves a Reference from the collection of
                |     SfmReferences.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] The index of the parameter 
                |         oParm
                |             [out] The parameter 
                | 
                |     Returns:
                |         Error code
                | 
                |         Example
                |         :
                |             This example retrieves 'i'th Reference from a list of
                |             References
                | 
                |               Dim ListofRef As SfmReferences
                |               Set Ref1 = ListofRef.Item(i)

        :param cat_variant i_index:
        :rtype: Reference
        """
        return Reference(self.sfm_references.Item(i_index))

    def __repr__(self):
        return f'SFMReferences(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_body_element import SWKBodyElement
from pycatia.dnb_human_modeling_interfaces.swkdof import SWKDOF
from pycatia.system_interfaces.any_object import AnyObject


class SWKSegment(SWKBodyElement):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKBodyElement
                |                         SWKSegment
                | 
                | This interface deals with a segment of a manikin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_segment = com_object

    @property
    def attach_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttachSize() As long (Read Only)
                | 
                |     Returns the number of objects currently attached to the
                |     segment.

        :rtype: int
        """

        return self.swk_segment.AttachSize

    @property
    def end_position_x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPositionX() As double (Read Only)
                | 
                |     Returns the global x coordinate of the endpoint of the
                |     segment.

        :rtype: float
        """

        return self.swk_segment.EndPositionX

    @property
    def end_position_y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPositionY() As double (Read Only)
                | 
                |     Returns the global y coordinate of the endpoint of the
                |     segment.

        :rtype: float
        """

        return self.swk_segment.EndPositionY

    @property
    def end_position_z(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPositionZ() As double (Read Only)
                | 
                |     Returns the global z coordinate of the endpoint of the
                |     segment.

        :rtype: float
        """

        return self.swk_segment.EndPositionZ

    @property
    def is_dof_at0(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsDOFAt0() As boolean (Read Only)
                | 
                |     Returns True if there is a DOF at index 0, False otherwise.

        :rtype: bool
        """

        return self.swk_segment.IsDOFAt0

    @property
    def is_dof_at1(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsDOFAt1() As boolean (Read Only)
                | 
                |     Returns True if there is a DOF at index 1, False otherwise.

        :rtype: bool
        """

        return self.swk_segment.IsDOFAt1

    @property
    def is_dof_at2(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsDOFAt2() As boolean (Read Only)
                | 
                |     Returns True if there is a DOF at index 2, False otherwise.

        :rtype: bool
        """

        return self.swk_segment.IsDOFAt2

    @property
    def is_on_hand(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsOnHand() As boolean (Read Only)
                | 
                |     This property is True if this segment belongs to the manikin's hand.

        :rtype: bool
        """

        return self.swk_segment.IsOnHand

    @property
    def is_on_left_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsOnLeftSide() As boolean (Read Only)
                | 
                |     This property is True if this segment is on the left side of the manikin.

        :rtype: bool
        """

        return self.swk_segment.IsOnLeftSide

    @property
    def is_on_right_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsOnRightSide() As boolean (Read Only)
                | 
                |     This property is True if this segment is on the right side of the manikin.

        :rtype: bool
        """

        return self.swk_segment.IsOnRightSide

    @property
    def is_on_spine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsOnSpine() As boolean (Read Only)
                | 
                |     This property is True if this segment belongs to the manikin's spine.

        :rtype: bool
        """

        return self.swk_segment.IsOnSpine

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double (Read Only)
                | 
                |     Returns the length of the segment, in centimeters.

        :rtype: float
        """

        return self.swk_segment.Length

    @property
    def mirror_segment(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MirrorSegment() As CATBaseDispatch (Read Only)
                | 
                |     This property returns the equivalent segment, but on the opposite side
                |     (ex.: right leg <-> left leg).

        :rtype: AnyObject
        """

        return AnyObject(self.swk_segment.MirrorSegment)

    @property
    def nb_do_fs(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbDOFs() As long (Read Only)
                | 
                |     Returns the number of degrees of freedom on the current segment.
                |     Each segment can have up to three degrees of freedom.
                |     Therefore the value of this property will never be higher than 3.

        :rtype: int
        """

        return self.swk_segment.NbDOFs

    def apply_position(self, pi_position_increment: tuple, pi_start_segment: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyPosition(CATSafeArrayVariant piPositionIncrement,
                | CATBSTR piStartSegment)
                | 
                |     Applies a new relative position for the segment.
                | 
                |     Parameters:
                | 
                |         piPositionIncrement
                |             The new position to combine with the segment's current
                |             position.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                |         piStartSegment
                |             The short name of the first segment of the kinematics chain. The
                |             short name specified has to identify a valid segment, which is an ancestor of
                |             the current one. For instance, is the segment to position is the right hand,
                |             then that start segment might be "RSArCl" (right clavicular). If the string
                |             "Default" is specified, then the start segment will be automatically chosen.
                |             
                | 
                |     Example:
                | 
                |           This example sets the segment to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.GetItem("LSHaCPr").ApplyPosition
                |          myPosition

        :param tuple pi_position_increment:
        :param str pi_start_segment:
        :rtype: None
        """
        return self.swk_segment.ApplyPosition(pi_position_increment, pi_start_segment)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'apply_position'
        # # vba_code = """
        # # Public Function apply_position(swk_segment)
        # #     Dim piPositionIncrement (2)
        # #     swk_segment.ApplyPosition piPositionIncrement
        # #     apply_position = piPositionIncrement
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def attach(self, pi_object_to_attach: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Attach(AnyObject piObjectToAttach)
                | 
                |     Attach a geometry to the segment.
                | 
                |     Parameters:
                | 
                |         piObjectToAttach
                |             The object to attach. This object must be a movable object. Once
                |             the attach relationship is made, the object's postition will be updated every
                |             time the segment moves.

        :param AnyObject pi_object_to_attach:
        :rtype: None
        """
        return self.swk_segment.Attach(pi_object_to_attach.com_object)

    def create_reach_envelope(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateReachEnvelope()
                | 
                |     This method creates and displayed the reach envelope on the current
                |     segment. This segment must be part of the hand, otherwise an error code is
                |     returned.
                |     Property IsOnHand can be used to check whether the segment is located on
                |     the hand.

        :rtype: None
        """
        return self.swk_segment.CreateReachEnvelope()

    def destroy_reach_envelope(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DestroyReachEnvelope()
                | 
                |     This method destroys the reach envelope previously created for this
                |     segment.

        :rtype: None
        """
        return self.swk_segment.DestroyReachEnvelope()

    def detach(self, pi_object_to_detach: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Detach(AnyObject piObjectToDetach)
                | 
                |     Detach a geometry previously attached to the segment.
                | 
                |     Parameters:
                | 
                |         piObjectToDetach
                |             The object to detach. This object's will no longer be driven by the
                |             segment's position.

        :param AnyObject pi_object_to_detach:
        :rtype: None
        """
        return self.swk_segment.Detach(pi_object_to_detach.com_object)

    def detach_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DetachAll()
                | 
                |     Detach all objects attached so far to the segment.

        :rtype: None
        """
        return self.swk_segment.DetachAll()

    def get_attached_object(self, pi_index: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttachedObject(long piIndex) As AnyObject
                | 
                |     Retrieve one object currently attached to the segment.
                | 
                |     Parameters:
                | 
                |         piIndex
                |             The index of the object to retrieve. First attached object is at
                |             index 0.

        :param int pi_index:
        :rtype: AnyObject
        """
        return AnyObject(self.swk_segment.GetAttachedObject(pi_index))

    def get_dof(self, pi_dof_number: int) -> SWKDOF:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDOF(long piDOFNumber) As SWKDOF
                | 
                |     Returns a specific degree of freedom of the segment.
                |     A segment may have up to three degrees of freedom,
                |     and these are numbered from 0 to 2.
                |     However, the degrees of freedom do not always have
                |     consecutive indices. For instance the forearm
                |     has 2 DOFs, but these are numbered 0 and 2.
                |     That is why the set of DOFs under a segment cannot
                |     be properly accessed as if it was a collection.
                |     To loop through the degrees of freedom of a segment,
                |     one should test the value of properties IsDOFAt0, IsDOFAt1 or IsDOFAt2, and
                |     work with the
                |     DOF only if the value of one of the corresponding property
                |     is
                |     True.
                | 
                |     Parameters:
                | 
                |         piDOFNumber
                |             The index of the DOF to retrieve.
                |             This parameter must be either 0, 1 or 2.

        :param int pi_dof_number:
        :rtype: SWKDOF
        """
        return SWKDOF(self.swk_segment.GetDOF(pi_dof_number))

    def get_ik_offset(self, po_offset: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIKOffset(CATSafeArrayVariant poOffset)
                | 
                |     Returns:
                |         The IK offset for this segment.

        :param tuple po_offset:
        :rtype: None
        """
        return self.swk_segment.GetIKOffset(po_offset)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_ik_offset'
        # # vba_code = """
        # # Public Function get_ik_offset(swk_segment)
        # #     Dim poOffset (2)
        # #     swk_segment.GetIKOffset poOffset
        # #     get_ik_offset = poOffset
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_ik_position(self, po_ik_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIKPosition(CATSafeArrayVariant poIKPosition)
                | 
                |     Returns:
                |         The position used for IK on this segment.

        :param tuple po_ik_position:
        :rtype: None
        """
        return self.swk_segment.GetIKPosition(po_ik_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_ik_position'
        # # vba_code = """
        # # Public Function get_ik_position(swk_segment)
        # #     Dim poIKPosition (2)
        # #     swk_segment.GetIKPosition poIKPosition
        # #     get_ik_position = poIKPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_attached(self, pi_object: AnyObject) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAttached(AnyObject piObject) As boolean
                | 
                |     Returns:
                |         true if the object passed in the parameter is attached to the segment,
                |         false otherwise.

        :param AnyObject pi_object:
        :rtype: bool
        """
        return self.swk_segment.IsAttached(pi_object.com_object)

    def is_object_reachable(self, pi_object: AnyObject) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsObjectReachable(AnyObject piObject) As boolean
                | 
                |     Reachability check.
                | 
                |     Returns:
                |         true if the object passed is reachable by the segment, false otherwise.
                |         The position taken is that of the center of the object.

        :param AnyObject pi_object:
        :rtype: bool
        """
        return self.swk_segment.IsObjectReachable(pi_object.com_object)

    def is_reachable(self, pi_x: float, pi_y: float, pi_z: float) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsReachable(double piX,
                | double piY,
                | double piZ) As boolean
                | 
                |     Reachability check.
                | 
                |     Returns:
                |         true if the location expressed in the coordinates is reachable by the
                |         segment, false otherwise.

        :param float pi_x:
        :param float pi_y:
        :param float pi_z:
        :rtype: bool
        """
        return self.swk_segment.IsReachable(pi_x, pi_y, pi_z)

    def lock_posture(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LockPosture(long piDOFId)
                | 
                |     Lock the posture of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.LockPosture(pi_dof_id)

    def mirror_copy_angular_limitations(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MirrorCopyAngularLimitations(long piDOFId)
                | 
                |     Mirror copy the angular limitations of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.MirrorCopyAngularLimitations(pi_dof_id)

    def mirror_copy_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MirrorCopyPosture()
                | 
                |     Copy the posture on the equivalent segment, on the other side of the
                |     manikin. For instance, it copies the posture from the right leg to the left
                |     leg.

        :rtype: None
        """
        return self.swk_segment.MirrorCopyPosture()

    def mirror_copy_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MirrorCopyPrefAngles(long piDOFId)
                | 
                |     Mirror copy the preferred angles of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.MirrorCopyPrefAngles(pi_dof_id)

    def optimize(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Optimize(long piDOFId)
                | 
                |     Sets the limits to match the best PrefAngle for the DOF piDOFId

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.Optimize(pi_dof_id)

    def remove_limits(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveLimits(long piDOFId)
                | 
                |     Removes the angular limitations of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.RemoveLimits(pi_dof_id)

    def reset_angular_limitations(self, pi_dof_id: int, pi_reset: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAngularLimitations(long piDOFId,
                | long piReset)
                | 
                |     Reset the angular limitations of the segment depending on piReset: 0 -> 2
                |     OR 3 OR 4 depending of the first encountered. 1 -> 2 AND 3 AND 4 2 -> Unlock
                |     the value 3 -> Restore the angular limitations if it is "No Limits" 4 -> Set
                |     back the angular limitations to their default value (50.0%)

        :param int pi_dof_id:
        :param int pi_reset:
        :rtype: None
        """
        return self.swk_segment.ResetAngularLimitations(pi_dof_id, pi_reset)

    def reset_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPosture()
                | 
                |     Set the segment's posture back to its default position.

        :rtype: None
        """
        return self.swk_segment.ResetPosture()

    def reset_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPrefAngles(long piDOFId)
                | 
                |     Reset the preferred angles of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.ResetPrefAngles(pi_dof_id)

    def set_percentage(self, pi_percentage: float, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPercentage(double piPercentage,
                | long piDOFId)
                | 
                |     Sets the angular limitations to a percentage for the DOF piDOFId

        :param float pi_percentage:
        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.SetPercentage(pi_percentage, pi_dof_id)

    def set_position(self, pi_new_position: tuple, pi_start_segment: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant piNewPosition,
                | CATBSTR piStartSegment)
                | 
                |     Sets a new absolute position for the segment.
                | 
                |     Parameters:
                | 
                |         piNewPosition
                |             The new position to place the segment.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                |         piStartSegment
                |             The short name of the first segment of the kinematics chain. The
                |             short name specified has to identify a valid segment, which is an ancestor of
                |             the current one. For instance, is the segment to position is the right hand,
                |             then that start segment might be "RSArCl" (right clavicular). If the string
                |             "Default" is specified, then the start segment will be automatically chosen.
                |
                |     Example:
                | 
                |           This example sets the segment to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.GetItem("LSHaCPr").SetPosition myPosition,
                |          "Default"

        :param tuple pi_new_position:
        :param str pi_start_segment:
        :rtype: None
        """
        return self.swk_segment.SetPosition(pi_new_position, pi_start_segment)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(swk_segment)
        # #     Dim piNewPosition (2)
        # #     swk_segment.SetPosition piNewPosition
        # #     set_position = piNewPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def swap_angular_limitations(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapAngularLimitations(long piDOFId)
                | 
                |     Swap the angular limitations of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.SwapAngularLimitations(pi_dof_id)

    def swap_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapPosture()
                | 
                |     Swap the posture with the equivalent segment, on the other side of the
                |     manikin. For instance, the right leg takes the posture of the left leg, and
                |     vice versa.

        :rtype: None
        """
        return self.swk_segment.SwapPosture()

    def swap_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapPrefAngles(long piDOFId)
                | 
                |     Swap the preferred angles of the segment.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_segment.SwapPrefAngles(pi_dof_id)

    def __repr__(self):
        return f'SWKSegment(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_ergo_carry import SWKErgoCarry
from pycatia.dnb_human_modeling_interfaces.swk_ergo_lift_lower import SWKErgoLiftLower
from pycatia.dnb_human_modeling_interfaces.swk_ergo_push_pull import SWKErgoPushPull
from pycatia.dnb_human_modeling_interfaces.swk_ergo_rula import SWKErgoRULA
from pycatia.system_interfaces.any_object import AnyObject


class SWKErgo(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKErgo
                | 
                | This interface groups the properties giving access to all the ergonomic studies
                | that can be performed on a manikin.
                | 
                | Its main purpose is to provide bridges to the specific ergonomic analysis
                | interfaces.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_ergo = com_object

    @property
    def carry(self) -> SWKErgoCarry:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Carry() As SWKErgoCarry (Read Only)
                | 
                |     Returns the object for a carry analysis. The Carry can also be obtained by
                |     invoking method GetItem (from AnyObject) with the character string "Carry" as
                |     an argument.

        :rtype: SWKErgoCarry
        """

        return SWKErgoCarry(self.swk_ergo.Carry)

    @property
    def lift_lower(self) -> SWKErgoLiftLower:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LiftLower() As SWKErgoLiftLower (Read Only)
                | 
                |     Returns the object for a lift/lower analysis. The Lift/Lower can also be
                |     obtained by invoking method GetItem (from AnyObject) with the character string
                |     "LiftLower" as an argument.

        :rtype: SWKErgoLiftLower
        """

        return SWKErgoLiftLower(self.swk_ergo.LiftLower)

    @property
    def push_pull(self) -> SWKErgoPushPull:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PushPull() As SWKErgoPushPull (Read Only)
                | 
                |     Returns the object for a push/pull analysis. The Push/Pull can also be
                |     obtained by invoking method GetItem (from AnyObject) with the character string
                |     "PushPull" as an argument.

        :rtype: SWKErgoPushPull
        """

        return SWKErgoPushPull(self.swk_ergo.PushPull)

    @property
    def rula(self) -> SWKErgoRULA:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RULA() As SWKErgoRULA (Read Only)
                | 
                |     Returns the object for a RULA analysis. The RULA object can also be
                |     obtained by invoking method GetItem (from AnyObject) with the character string
                |     "RULA" as an argument.

        :rtype: SWKErgoRULA
        """

        return SWKErgoRULA(self.swk_ergo.RULA)

    def __repr__(self):
        return f'SWKErgo(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppEnvironment(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppEnvironment
                | 
                | Manage the application environment in a schematic session.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_environment = com_object

    def app_clean_up_when_application_ends(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCleanUpWhenApplicationEnds()
                | 
                |     Initialize environment when schematic application ends.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppEnvironment
                |           ...
                |          objThisIntf.AppCleanUpWhenApplicationEnds

        :rtype: None
        """
        return self.sch_app_environment.AppCleanUpWhenApplicationEnds()

    def app_init_when_application_starts(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppInitWhenApplicationStarts()
                | 
                |     Initialize environment when schematic application starts.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppEnvironment
                |           ...
                |          objThisIntf.AppInitWhenApplicationStarts

        :rtype: None
        """
        return self.sch_app_environment.AppInitWhenApplicationStarts()

    def app_load_feat_files(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppLoadFeatFiles()
                | 
                |     Load all the necessary feat files.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppEnvironment
                |           ...
                |          objThisIntf.AppLoadFeatFiles

        :rtype: None
        """
        return self.sch_app_environment.AppLoadFeatFiles()

    def __repr__(self):
        return f'SchAppEnvironment(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.transformation_shape import TransformationShape
from pycatia.system_interfaces.any_object import AnyObject


class Mirror(TransformationShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.TransformationShape
                |                             Mirror
                | 
                | Represents the mirror shape.
                | It duplicates a shape with respect to a planar mirroring element, such as a
                | planar face or a plane.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mirror = com_object

    @property
    def mirroring_object(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MirroringObject() As AnyObject (Read Only)
                | 
                |     Returns the mirroring Object.

        :rtype: AnyObject
        """

        return AnyObject(self.mirror.MirroringObject)

    @property
    def mirroring_plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MirroringPlane() As Reference
                | 
                |     Returns or sets the mirroring reference plane. It can be a plane, or a
                |     plane face.
                |     To set the property, you can use the following Boundary object:
                |     PlanarFace.
                | 
                |     Example:
                |         The following example returns in ref the mirroring reference plane of
                |         the mirroring firstMirroring, and then sets it to the created
                |         MyRef:
                | 
                |          Set ref = firstMirroring.MirroringPlane
                |          Set MyRef = part.CreateReferenceFromGeometry (plane)
                |          firstMirroring.MirroringPlane = MyRef

        :rtype: Reference
        """

        return Reference(self.mirror.MirroringPlane)

    @mirroring_plane.setter
    def mirroring_plane(self, value: Reference):
        """
        :param Reference value:
        """

        self.mirror.MirroringPlane = value.com_object

    def __repr__(self):
        return f'Mirror(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_temperature import ABQTemperature


class ABQInitialTemperature(ABQTemperature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQTemperature
                |                         ABQInitialTemperature
                | 
                | Represents an Abaqus initial temperature object
                | (ABQInitialTemperature).
                | Role: Access an Abaqus initial temperature object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_initial_temperature = com_object

    @property
    def step_num(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StepNum() As short
                | 
                |     Sets or returns the step number from which to read the temperature data.

        :rtype: int
        """

        return self.abq_initial_temperature.StepNum

    @step_num.setter
    def step_num(self, value: int):
        """
        :param int value:
        """

        self.abq_initial_temperature.StepNum = value

    def __repr__(self):
        return f'ABQInitialTemperature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.shot import Shot
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Shots(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Shots
                | 
                | The collection of all shot objects contained in the current
                | sampled.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Shot)
        self.shots = com_object

    def append(self, i_shot: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Append(CATBaseDispatch iShot)
                | 
                |     Adds a shot to the end of the shots collection.
                | 
                |     Parameters:
                | 
                |         iShot
                |             The shot to be added 
                |         Example:
                |             The following example adds a shot (called myShot to the shots
                |             collection.
                | 
                |              Shots.Append (myShot)

        :param AnyObject i_shot:
        :rtype: None
        """
        return self.shots.Append(i_shot.com_object)

    def create_shot(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateShot() As CATBaseDispatch
                | 
                |     Creates a new shot and adds it to the Shots collection.
                | 
                |     Returns:
                |         The created shot 
                |     Example:
                |         The following example creates a shot newShot in the Shots
                |         collection.
                | 
                |          Dim newShot
                |          Set newShot = Shots.CreateShot

        :rtype: AnyObject
        """
        return self.shots.CreateShot()

    def create_specific_shot(self, i_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSpecificShot(CATBSTR iType) As CATBaseDispatch
                | 
                |     Creates a new shot of a specific type and adds it to the Shots
                |     collection.
                | 
                |     Parameters:
                | 
                |         iType
                |             Specifies the type of the shot to be created. The legal values are
                |             FITShotPoints, FITShotDouble, FITShotSimple and FITShotGeneric. These different
                |             types correspond to the need of creating different shots for different types of
                |             objects. 
                | 
                |     Returns:
                |         The created Shot 
                |     Example:
                |         The following example creates a shot shot in the Shots
                |         collection.
                | 
                |          Set newShots = Shots.CreateShot (FITSHOTDouble)

        :param str i_type:
        :rtype: AnyObject
        """
        return self.shots.CreateSpecificShot(i_type)

    def insert_after(self, i_index: int, i_shot: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InsertAfter(short iIndex,
                | CATBaseDispatch iShot)
                | 
                |     Adds a shot to a specific location to the shots
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The value of the location of an already existing shot. Then when
                |             inserting a new shot, it will be placed after it. It is a positive integer,
                |             with the range of 1 to the value of the last shot.
                |             
                |         iShot
                |             The shot to be added 
                |         Example:
                |             The following example inserts a shot after the second
                |             shot.
                | 
                |              Shots.InsertAfter (2, myShot)

        :param int i_index:
        :param AnyObject i_shot:
        :rtype: None
        """
        return self.shots.InsertAfter(i_index, i_shot.com_object)

    def item(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As CATBaseDispatch
                | 
                |     Returns a shot using its index from the colection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the item to retrieve from the collection of shots.
                |             Numerically, the index value corresponds to the rank of the shot in the
                |             collection (ie. the first is 1, second is 2, ...).
                |             
                | 
                |     Returns:
                |         The retrieved Shot 
                |     Example:
                |         The following example retrieves the second shot from the Shots
                |         collection.
                | 
                |          Dim myShot
                |          Set myShot = myShots.Item (2)

        :param cat_variant i_index:
        :rtype: AnyObject
        """
        return self.shots.Item(i_index)

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a shot from the collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the shot to remove from the collection of the shots.
                |             Numerically, the index value corresponds to the rank of the shot in the
                |             collection (ie. the first is 1, second is 2, ...).
                |             
                |         Example:
                |             The following example removes the third shot from the Shots
                |             collection of the active document.
                | 
                |              Shots.Remove (3)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.shots.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(shots)
        # #     Dim iIndex (2)
        # #     shots.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Shots(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.system_interfaces.any_object import AnyObject


class SchCatalogRoute(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCatalogRoute
                | 
                | Manage a schematic route catalog.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_catalog_route = com_object

    def query_drop_ability(self, o_b_yes: bool, o_route_ref: SchRoute, o_pointed_to_grr: SchGRR) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub QueryDropAbility(boolean oBYes,
                | SchRoute oRouteRef,
                | SchGRR oPointedToGRR)
                | 
                |     Check to see if it is OK to be dropped to the current
                |     document.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to be dropped. 
                |         oRouteRef
                |             Route reference. 
                |         oPointedToGRR
                |             Graphical representation of a route pointed-to by the catalog
                |             component 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCatalogRoute
                |          Dim bVar1 As boolean
                |          Dim objArg2 As SchRoute
                |          Dim objArg3 As SchGRR
                |           ...
                |          objThisIntf.QueryDropAbilitybVar1,objArg2,objArg3

        :param bool o_b_yes:
        :param SchRoute o_route_ref:
        :param SchGRR o_pointed_to_grr:
        :rtype: None
        """
        return self.sch_catalog_route.QueryDropAbility(o_b_yes, o_route_ref.com_object, o_pointed_to_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'query_drop_ability'
        # # vba_code = """
        # # Public Function query_drop_ability(sch_catalog_route)
        # #     Dim oBYes (2)
        # #     sch_catalog_route.QueryDropAbility oBYes
        # #     query_drop_ability = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCatalogRoute(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.system_interfaces.any_object import AnyObject


class SchGRRCntr(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRCntr
                | 
                | Manage the graphical representation of a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_cntr = com_object

    def get_symbol(self, o_grr: SchGRR, o_e_symbol_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSymbol(SchGRR oGRR,
                | CatSchIDLCntrSymbolType oESymbolType)
                | 
                |     Get the graphical primitive of a connector.
                | 
                |     Parameters:
                | 
                |         oGRR
                |             The graphical primitive (ditto) used to represent a connector.
                |             
                |         oESymbolType
                |             Connector symbol type such as: point, point/vector, OnOffSheet,
                |             LineBoundary. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRCntr
                |          Dim objArg1 As SchGRR
                | 
                |           ...
                |          objThisIntf.GetSymbolobjArg1,CatSchIDLCntrSymbolType_Enum

        :param SchGRR o_grr:
        :param int o_e_symbol_type: enum cat_sch_idl_cntr_symbol_type
        :rtype: None
        """
        return self.sch_grr_cntr.GetSymbol(o_grr.com_object, o_e_symbol_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_symbol'
        # # vba_code = """
        # # Public Function get_symbol(sch_grr_cntr)
        # #     Dim oGRR (2)
        # #     sch_grr_cntr.GetSymbol oGRR
        # #     get_symbol = oGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_symbol(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveSymbol()
                | 
                |     Remove the graphical primitive used as the connector's symbol. The default
                |     connector's symbol type will be set to point.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchGRRCntr
                |           ...
                |          objThisIntf.RemoveSymbol

        :rtype: None
        """
        return self.sch_grr_cntr.RemoveSymbol()

    def set_symbol(self, i_grr_symbol: SchGRR, i_e_symbol_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSymbol(SchGRR iGRRSymbol,
                | CatSchIDLCntrSymbolType iESymbolType)
                | 
                |     Set the symbol or graphics used to represent a connector.
                | 
                |     Parameters:
                | 
                |         iGRRSymbol
                |             The graphical primitive (detail) to be used as the connector's
                |             symbol. iGRRSymbol can be NULL if iESymbolType is a point or point/vector.
                |             
                |         iESymbolType
                |             Connector symbol type such as: point, point/vector, OnOffSheet,
                |             LineBoundary. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRCntr
                |          Dim objArg1 As SchGRR
                |           ...
                |          objThisIntf.SetSymbolobjArg1,CatSchIDLCntrSymbolType_Enum

        :param SchGRR i_grr_symbol:
        :param int i_e_symbol_type: enum cat_sch_idl_cntr_symbol_type
        :rtype: None
        """
        return self.sch_grr_cntr.SetSymbol(i_grr_symbol.com_object, i_e_symbol_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_symbol'
        # # vba_code = """
        # # Public Function set_symbol(sch_grr_cntr)
        # #     Dim iGRRSymbol (2)
        # #     sch_grr_cntr.SetSymbol iGRRSymbol
        # #     set_symbol = iGRRSymbol
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchGRRCntr(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.structure_interfaces.str_foundation import StrFoundation
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class StrFoundations(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     StrFoundations
                | 
                | A collection of the Foundation objects contained in a given Product object of a
                | ProductDocument object.
                | A Product object aggregates zero or one Foundations collection. This collection
                | is retrieved using the Product.GetTechnologicalObject method of the
                | product.
                | 
                | Example:
                | 
                |       The following example retrieves the Foundation collection from
                |       the
                |      oProduct Product.
                |      
                | 
                |      Dim oFoundations as AnyObject
                |      Set oFoundations = oProduct.GetTechnologicalObject("StructureFoundations")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=StrFoundation)
        self.str_foundations = com_object

    def item(self, i_index: cat_variant) -> StrFoundation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StrFoundation
                | 
                |     Returns a Foundation from its index in the Foundations
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the Foundation to retrieve in the collection of
                |             Foundations. This index can either be the rank of the Foundation in the
                |             collection or the name you assign to the Foundation. As a numerics, this index
                |             is the rank of the Foundation in the collection. The index of the first
                |             Foundation in the collection is 1, and the index of the last Foundation is
                |             Count. As a string, it is the name you assigned to the Foundation using the
                |             
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved Foundation 
                |     Example:
                | 
                |           The following example returns in ThisFoundation the third
                |           Foundation,
                |          and in ThatFoundation the Foundation named
                |          Column_1 in the Assembly_1 Foundation collection.
                |          
                | 
                |          Dim ThisFoundation As Foundation
                |          Set ThisFoundation = Assembly_1.Item(3)
                |          Dim ThatFoundation As Foundation
                |          Set ThatFoundation = Assembly.Item("Column_1")

        :param cat_variant i_index:
        :rtype: StrFoundation
        """
        return StrFoundation(self.str_foundations.Item(i_index))

    def __repr__(self):
        return f'StrFoundations(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class StrNibblingFeature(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrNibblingFeature
                | 
                | Represents a Nibbling Feature.
                | Type, SubType and Extrapolation Offset can be defined for this nibbling
                | feature.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_nibbling_feature = com_object

    @property
    def sub_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubType() As CATBSTR
                | 
                |     Returns or Sets Nibbling SubType on Current Nibbling.
                | 
                |     Example:
                | 
                |           
                | 
                |           Dim NibblingFeature As StrNibblingFeature
                |           Set NibblingFeature = FeatureFactory.AddNibbling(List, "Remove")
                |           Dim NibbSubType As String
                |           NibbSubType = NibblingFeature1.SubType
                |          'Set the SubType
                |           NibblingFeature1.SubType ="ButtButt"

        :rtype: str
        """

        return self.str_nibbling_feature.SubType

    @sub_type.setter
    def sub_type(self, value: str):
        """
        :param str value:
        """

        self.str_nibbling_feature.SubType = value

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR
                | 
                |     Returns or Sets Nibbling Type on Current Nibbling.
                | 
                |     Example:
                | 
                |           
                | 
                |           Dim NibblingFeature As StrNibblingFeature
                |           Set NibblingFeature = FeatureFactory.AddNibbling(List, "Remove")
                |           Dim NibbType As String
                |           NibbType = NibblingFeature1.Type
                |           'Set the Type
                |           NibblingFeature1.Type ="LongPoint"

        :rtype: str
        """

        return self.str_nibbling_feature.Type

    @type.setter
    def type(self, value: str):
        """
        :param str value:
        """

        self.str_nibbling_feature.Type = value

    def get_offset_for_extrapolate(self, i_offset_for_extrapolate: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOffsetForExtrapolate(CATBSTR iOffsetForExtrapolate)
                | 
                |     Sets the Extrapolation offset value on Current Nibbling
                |     Feature.
                | 
                |     Parameters:
                | 
                |         iOffsetForExtrapolate
                |             [in] Default Value:"5mm" 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example
                |         :
                |             This example Applies Extrapolation offset.
                | 
                |               Dim NibblingFeature As StrNibblingFeature
                |               Set NibblingFeature = FeatureFactory.AddNibbling(List, "Remove")
                |               NibblingFeature.GetOffsetForExtrapolate("0mm")
                |              
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :param str i_offset_for_extrapolate:
        :rtype: None
        """
        return self.str_nibbling_feature.GetOffsetForExtrapolate(i_offset_for_extrapolate)

    def __repr__(self):
        return f'StrNibblingFeature(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchCntrLocation(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCntrLocation
                | 
                | Manage the location of a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_cntr_location = com_object

    def get_align_vector(self, i_grr: SchGRR, o_db2_align_vector: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAlignVector(SchGRR iGRR,
                | SchListOfDoubles oDb2AlignVector)
                | 
                |     Get the current alignment vector of the connector.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the graphical primitive or the graphical image or the
                |             graphical primitives of the owner of the connector.
                |             
                |         oDb2AlignVector
                |             X-Y component of the current alignment vector of the connector.
                |             
                |     Example:
                |
                |          Dim objThisIntf As SchCntrLocation
                |          Dim objArg1 As SchGRR
                |          Dim objArg2 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetAlignVectorobjArg1,objArg2

        :param SchGRR i_grr:
        :param SchListOfDoubles o_db2_align_vector:
        :rtype: None
        """
        return self.sch_cntr_location.GetAlignVector(i_grr.com_object, o_db2_align_vector.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_align_vector'
        # # vba_code = """
        # # Public Function get_align_vector(sch_cntr_location)
        # #     Dim iGRR (2)
        # #     sch_cntr_location.GetAlignVector iGRR
        # #     get_align_vector = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_position(self, i_grr: SchGRR, o_db2_position: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPosition(SchGRR iGRR,
                | SchListOfDoubles oDb2Position)
                | 
                |     Get the current position of the connector in absolute
                |     coordinates.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the graphical primitive or the graphical image or the
                |             graphical primitives of the owner of the connector.
                |             
                |         oDb2Position
                |             Absolute X-Y coordinates of the current position of the connector.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchCntrLocation
                |          Dim objArg1 As SchGRR
                |          Dim objArg2 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetPositionobjArg1,objArg2

        :param SchGRR i_grr:
        :param SchListOfDoubles o_db2_position:
        :rtype: None
        """
        return self.sch_cntr_location.GetPosition(i_grr.com_object, o_db2_position.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_position'
        # # vba_code = """
        # # Public Function get_position(sch_cntr_location)
        # #     Dim iGRR (2)
        # #     sch_cntr_location.GetPosition iGRR
        # #     get_position = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_relative_position(self, o_db2_relative_position: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRelativePosition(SchListOfDoubles
                | oDb2RelativePosition)
                | 
                |     Get the current position of the connector in relative
                |     coordinates.
                | 
                |     Parameters:
                | 
                |         oDb2RelativePosition
                |             relative X-Y coordinates of the current position of the connector.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchCntrLocation
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetRelativePositionobjArg1

        :param SchListOfDoubles o_db2_relative_position:
        :rtype: None
        """
        return self.sch_cntr_location.GetRelativePosition(o_db2_relative_position.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_relative_position'
        # # vba_code = """
        # # Public Function get_relative_position(sch_cntr_location)
        # #     Dim oDb2RelativePosition (2)
        # #     sch_cntr_location.GetRelativePosition oDb2RelativePosition
        # #     get_relative_position = oDb2RelativePosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_align_vector(self, i_grr: SchGRR, i_db2_align_vector: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAlignVector(SchGRR iGRR,
                | CATSafeArrayVariant iDb2AlignVector)
                | 
                |     Set the current alignment vector of the connector.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the graphical primitive or the graphical image or the
                |             graphical primitives of the owner of the connector.
                |             
                |         iDb2AlignVector
                |             X-Y component of the current alignment vector of the connector to
                |             be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrLocation
                |          Dim objArg1 As SchGRR
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetAlignVectorobjArg1,dbVar2

        :param SchGRR i_grr:
        :param tuple i_db2_align_vector:
        :rtype: tuple
        """
        return self.sch_cntr_location.SetAlignVector(i_grr.com_object, i_db2_align_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_align_vector'
        # # vba_code = """
        # # Public Function set_align_vector(sch_cntr_location)
        # #     Dim iGRR (2)
        # #     sch_cntr_location.SetAlignVector iGRR
        # #     set_align_vector = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_position(self, i_grr: SchGRR, i_db2_position: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(SchGRR iGRR,
                | CATSafeArrayVariant iDb2Position)
                | 
                |     Set the current position of the connector in absolute coordinates. All
                |     connectors on multi-images are affected because the relative position on
                |     connect will be changed accordingly.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the graphical primitive or the graphical image or the
                |             graphical primitives of the owner of the connector..
                |             
                |         iDb2Position
                |             absolute X-Y coordinates of the current position of the connector
                |             to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrLocation
                |          Dim objArg1 As SchGRR
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetPositionobjArg1,dbVar2

        :param SchGRR i_grr:
        :param tuple i_db2_position:
        :rtype: tuple
        """
        return self.sch_cntr_location.SetPosition(i_grr.com_object, i_db2_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(sch_cntr_location)
        # #     Dim iGRR (2)
        # #     sch_cntr_location.SetPosition iGRR
        # #     set_position = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_relative_position(self, i_db2_relative_position: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRelativePosition(CATSafeArrayVariant
                | iDb2RelativePosition)
                | 
                |     Set the current position of the connector in absolute
                |     coordinates.
                | 
                |     Parameters:
                | 
                |         iDb2RelativePosition
                |             relative X-Y coordinates of the current position of the connector
                |             to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrLocation
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetRelativePositiondbVar1

        :param tuple i_db2_relative_position:
        :rtype: tuple
        """
        return self.sch_cntr_location.SetRelativePosition(i_db2_relative_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relative_position'
        # # vba_code = """
        # # Public Function set_relative_position(sch_cntr_location)
        # #     Dim iDb2RelativePosition (2)
        # #     sch_cntr_location.SetRelativePosition iDb2RelativePosition
        # #     set_relative_position = iDb2RelativePosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCntrLocation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_member import SFMMember
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class SFMMemberSurfSurf(SFMMember):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                            CATStrFunctionalInterfaces.SfmMember
                |                                 SfmMemberSurfSurf
                | 
                | Interface to manage Member created by the intersection of two
                | surfaces.
                | Role: To manage member created by the intersection of two
                | surfaces.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member_surf_surf = com_object

    @property
    def first_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstSurface() As Reference
                | 
                |     Returns or sets the SuperMember's first surface.
                | 
                |     Example:
                |         This example retrieves in FirstSurface the first surface of the
                |         SuperMember feature.
                | 
                |          Dim Surface As Reference
                |          Set Surface = SuperMember.FirstSurface

        :rtype: Reference
        """

        return Reference(self.sfm_member_surf_surf.FirstSurface)

    @first_surface.setter
    def first_surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_surf_surf.FirstSurface = value.com_object

    @property
    def first_surface_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstSurfaceOffset() As double
                | 
                |     Returns or sets the SuperMember's first surface offset.
                | 
                |     Example:
                |         This example retrieves in Offset the first surface offset of the
                |         SuperMember feature.
                | 
                |          Dim Offset As Double
                |          Set Offset = SuperMember.FirstSurfaceOffset

        :rtype: float
        """

        return self.sfm_member_surf_surf.FirstSurfaceOffset

    @first_surface_offset.setter
    def first_surface_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_member_surf_surf.FirstSurfaceOffset = value

    @property
    def first_surface_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstSurfaceOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_member_surf_surf.FirstSurfaceOffsetParam)

    @property
    def first_surface_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstSurfaceOrientation() As long
                | 
                |     Returns or sets the SuperMember's first surface
                |     orientation.
                | 
                |     Example:
                |         This example retrieves in Orient the first surface orientation for
                |         SuperMember feature.
                | 
                |          Dim Orient As Integer
                |          Set Orient = SuperMember.FirstSurfaceOrientation

        :rtype: int
        """

        return self.sfm_member_surf_surf.FirstSurfaceOrientation

    @first_surface_orientation.setter
    def first_surface_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member_surf_surf.FirstSurfaceOrientation = value

    @property
    def second_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondSurface() As Reference
                | 
                |     Returns the SuperMember's second surface.
                | 
                |     Example:
                |         This example retrieves in Surface the second surface of the SuperMember
                |         feature.
                | 
                |          Dim Surface As Reference
                |          Set Surface = SuperMember.SecondSurface

        :rtype: Reference
        """

        return Reference(self.sfm_member_surf_surf.SecondSurface)

    @second_surface.setter
    def second_surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_surf_surf.SecondSurface = value.com_object

    @property
    def second_surface_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondSurfaceOffset() As double
                | 
                |     Returns or sets the SuperMember's second surface offset.
                | 
                |     Example:
                |         This example retrieves in Offset the second surface offset of the
                |         SuperMember feature.
                | 
                |          Dim Offset As Double
                |          Set Offset = SuperMember.SecondSurfaceOffset

        :rtype: float
        """

        return self.sfm_member_surf_surf.SecondSurfaceOffset

    @second_surface_offset.setter
    def second_surface_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_member_surf_surf.SecondSurfaceOffset = value

    @property
    def second_surface_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondSurfaceOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_member_surf_surf.SecondSurfaceOffsetParam)

    @property
    def second_surface_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondSurfaceOrientation() As long
                | 
                |     Returns or sets the SuperMember's second surface
                |     orientation.
                | 
                |     Example:
                |         This example retrieves in Orient the second surface orientation for
                |         SuperMember feature.
                | 
                |          Dim Orient As Integer
                |          Set Orient = SuperMember.SecondSurfaceOrientation

        :rtype: int
        """

        return self.sfm_member_surf_surf.SecondSurfaceOrientation

    @second_surface_orientation.setter
    def second_surface_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member_surf_surf.SecondSurfaceOrientation = value

    def __repr__(self):
        return f'SFMMemberSurfSurf(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.structure_interfaces.str_cutback import StrCutback
from pycatia.system_interfaces.any_object import AnyObject


class StrMemberExtremity(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrMemberExtremity
                | 
                | Represents an extremity of a member object.
                | One is called the start extremity and the other the end
                | extremity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_member_extremity = com_object

    @property
    def angle_cut(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleCut() As double (Read Only)
                | 
                |     Returns the angle cut for a member extremity.

        :rtype: float
        """

        return self.str_member_extremity.AngleCut

    @property
    def cutback(self) -> StrCutback:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Cutback() As StrCutback (Read Only)
                | 
                |     Returns the cutback object.

        :rtype: StrCutback
        """

        return StrCutback(self.str_member_extremity.Cutback)

    @property
    def input(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Input() As Reference
                | 
                |     Returns or sets the input object defining the extremity. The input object
                |     may not belong to the support object.

        :rtype: Reference
        """

        return Reference(self.str_member_extremity.Input)

    @input.setter
    def input(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_member_extremity.Input = value.com_object

    @property
    def offset(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Offset() As Parameter (Read Only)
                | 
                |     Returns the offset parameter defined on this extremity. This parameter can
                |     be null.

        :rtype: Parameter
        """

        return Parameter(self.str_member_extremity.Offset)

    @property
    def point(self) -> Point:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Point() As Point (Read Only)
                | 
                |     Returns the point defining the extremity. This point belongs to the support
                |     object.

        :rtype: Point
        """

        return Point(self.str_member_extremity.Point)

    def add_offset(self, i_offset: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddOffset(double iOffset)
                | 
                |     Adds an offset on the extremity. This method has to be used when the
                |     extremity has no offset already defined, else you will get an error.

        :param float i_offset:
        :rtype: None
        """
        return self.str_member_extremity.AddOffset(i_offset)

    def get_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCoordinates(CATSafeArrayVariant oCoordinates)
                | 
                |     Retrieves the coordinates of the extremity.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The coordinates of the the extremity

        :param tuple o_coordinates:
        :rtype: None
        """
        return self.str_member_extremity.GetCoordinates()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_coordinates'
        # # vba_code = """
        # # Public Function get_coordinates(str_member_extremity)
        # #     Dim oCoordinates (2)
        # #     str_member_extremity.GetCoordinates oCoordinates
        # #     get_coordinates = oCoordinates
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_cutback(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetCutback()
                | 
                |     Resets the defined cutback object.

        :rtype: None
        """
        return self.str_member_extremity.ResetCutback()

    def set_extremity_from_coordinates(self, i_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExtremityFromCoordinates(CATSafeArrayVariant
                | iCoordinates)
                | 
                |     Modifies the coordinates of the extremity defined by a
                |     point.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates to modify the extremity

        :param tuple i_coordinates:
        :rtype: None
        """
        return self.str_member_extremity.SetExtremityFromCoordinates(i_coordinates)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_extremity_from_coordinates'
        # # vba_code = """
        # # Public Function set_extremity_from_coordinates(str_member_extremity)
        # #     Dim iCoordinates (2)
        # #     str_member_extremity.SetExtremityFromCoordinates iCoordinates
        # #     set_extremity_from_coordinates = iCoordinates
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StrMemberExtremity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activities import ManufacturingActivities
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class MachiningProcess(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             MachiningProcess
                | 
                | MachiningProcess defines a set of properties and methods to apply a Machining
                | Process to a geometrical feature (design or manufacturing).
                | It refers to a Machining Process which has been defined in the Machining
                | Process view of a CATProcess file In the VB macro, be sure that the active
                | document is the target document where are located the insertion level and where
                | the instantiated activities will be created
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.machining_process = com_object

    @property
    def insertion_level(self) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InsertionLevel() As ManufacturingActivity
                | 
                |     This property defines the insertion level in the program receiving the
                |     resulting operations. It can be set to either the Manufacturing Program or one
                |     the Manufacturing Activities of the Manufacturing Program.
                | 
                |     Example:
                |         The following example sets the InsertionLevel property to the first
                |         Manufacturing Program as ManufacturingActivity Activity for the mpReference
                |         MachiningProcess which will be used for the Machining Process
                |         application:
                | 
                |          ...
                |          Dim programReference As ManufacturingActivity
                |          Set programReference = ... 
                |          Dim mpReference As MachiningProcess
                |          Set mpReference = ...
                |          mpReference.InsertionLevel = programReference

        :rtype: ManufacturingActivity
        """

        return ManufacturingActivity(self.machining_process.InsertionLevel)

    @insertion_level.setter
    def insertion_level(self, value: ManufacturingActivity):
        """
        :param ManufacturingActivity value:
        """

        self.machining_process.InsertionLevel = value

    def get_activities(self) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetActivities() As MfgActivities
                | 
                |     This method gets the Manufacturing Activities referenced by the Machining
                |     Process.
                | 
                |     Parameters:
                | 
                |         oMfgActivities
                |             The Manufacturing Activities list

        :rtype: MfgActivities
        """
        return ManufacturingActivities(self.machining_process.GetActivities())

    def insert_activity(self, i_activity_type: str,
                        i_referenced_activity: ManufacturingActivity) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func InsertActivity(CATBSTR iActivityType,
                | ManufacturingActivity iReferencedActivity) As
                | ManufacturingActivity
                | 
                |     This method creates and inserts a Manufacturing Activity in the Machining
                |     Process.
                | 
                |     Parameters:
                | 
                |         iActivityType
                |             The activity to be created type 
                |         iReferencedActivity
                |             The insertion level in the machining process: the machining process
                |             itself to insert at the beginning of the Machining Process
                |             
                |         oManufacturingActivity
                |             The inserted activity
                | 
                |             Example:
                |                 The following example executes the InsertActivity method to add
                |                 a drilling operation to the mpReference
                |                 MachiningProcess
                | 
                |                  ...
                |                  Dim mpReference As MachiningProcess
                |                  Set mpReference = ...
                |                  ...
                |                  Dim iActivityType As CATBSTR
                |                  Set iActivityType = Drilling
                |                  Dim iReferencedActivity As
                |                  CATIAManufacturingActivity
                |                  Set iReferencedActivity = MachiningProcess
                |                  Dim oManufacturingActivity As
                |                  CATIAManufacturingActivity
                |                  mpReference.InsertActivity(iActivityType,iReferencedActivity,oManufacturingActivity)

        :param str i_activity_type:
        :param ManufacturingActivity i_referenced_activity:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(
            self.machining_process.InsertActivity(i_activity_type, i_referenced_activity.com_object))

    def instantiate(self, i_feature: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Instantiate(AnyObject iFeature)
                | 
                |     This method enables to apply a Machining Process to an any feature. This
                |     one has to be available for all Manufacturing Activities inside the Machining
                |     Process. At the end of the Machining Process application, the InsertionLevel
                |     property is set to the last created Manufacturing Activity in the Manufacturing
                |     program
                | 
                |     Example:
                |         The following example executes the Instantiate method to apply the
                |         mpReference MachiningProcess to a DesignFeature selected
                |         feature
                | 
                |          ...
                |          Dim mpReference As MachiningProcess
                |          Set mpReference = ...
                |          ...
                |          Dim DesignFeature As AnyObject
                |          Set DesignFeature = ...
                |          ...
                |          mpReference.Instantiate(DesignFeature)

        :param AnyObject i_feature:
        :rtype: None
        """
        return self.machining_process.Instantiate(i_feature.com_object)

    def instantiate_in_product_context(self, i_feature: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InstantiateInProductContext(AnyObject iFeature,
                | Product iProduct)
                | 
                |     This method enables to apply a Machining Process to a given feature by
                |     taking into account the product from which it belongs to. This one has to be
                |     available for all Manufacturing Activities inside the Machining Process. At the
                |     end of the Machining Process application, the InsertionLevel property is set to
                |     the last created Manufacturing Activity in the Manufacturing
                |     program
                | 
                |     Parameters:
                | 
                |         iFeature
                |             The feature on which the Machining Process is instantiated
                |             
                |         iProduct
                |             The product containing the feature.
                | 
                |             Example:
                |                 The following example executes the Instantiate method to apply
                |                 the mpReference MachiningProcess to a iDesignFeature selected
                |                 feature
                | 
                |                  ...
                |                  Dim mpReference As MachiningProcess
                |                  Set mpReference = ...
                |                  ...
                |                  Dim iDesignFeature As AnyObject
                |                  Set iDesignFeature = ...
                |                  ...
                |                  Dim iProduct As Product
                |                  Set iProduct = ...
                |                  ...
                |                 mpReference.Instantiate(iDesignFeature,iProduct)

        :param AnyObject i_feature:
        :param Product i_product:
        :rtype: None
        """
        return self.machining_process.InstantiateInProductContext(i_feature.com_object, i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'instantiate_in_product_context'
        # # vba_code = """
        # # Public Function instantiate_in_product_context(machining_process)
        # #     Dim iFeature (2)
        # #     machining_process.InstantiateInProductContext iFeature
        # #     instantiate_in_product_context = iFeature
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MachiningProcess(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SystemConfiguration(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SystemConfiguration
                | 
                | Provides abstractions to resources which depend on the platform or the current
                | configuration.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.system_configuration = com_object

    @property
    def operating_system(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OperatingSystem() As CATBSTR (Read Only)
                | 
                |     Returns a string which identifies the operating system on which the
                |     application is currently running. Examples of identifiers include: intel_a,
                |     solaris_a, aix_a, win_a and hpux_a.
                | 
                |     Parameters:
                | 
                |         oOperatingSystem
                |             The operating system identifier.

        :rtype: str
        """

        return self.system_configuration.OperatingSystem

    @property
    def product_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProductCount() As long (Read Only)
                | 
                |     Returns the number of product names names currently known to the
                |     system.
                | 
                |     Parameters:
                | 
                |         oProductCount
                |             The number of product names currently known to the
                |             system.

        :rtype: int
        """

        return self.system_configuration.ProductCount

    @property
    def release(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Release() As long (Read Only)
                | 
                |     Returns the CATIA release number.
                | 
                |     Parameters:
                | 
                |         oVersion
                |             The CATIA release number.

        :rtype: int
        """

        return self.system_configuration.Release

    @property
    def service_pack(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ServicePack() As long (Read Only)
                | 
                |     Returns the CATIA service pack number.
                | 
                |     Parameters:
                | 
                |         oServicePack
                |             The CATIA service pack number.

        :rtype: int
        """

        return self.system_configuration.ServicePack

    @property
    def version(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Version() As long (Read Only)
                | 
                |     Returns the CATIA version number (usually version 5).
                | 
                |     Parameters:
                | 
                |         oVersion
                |             The CATIA version.

        :rtype: int
        """

        return self.system_configuration.Version

    def get_product_names(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetProductNames(CATSafeArrayVariant ioProductNames)
                | 
                |     Returns the product names of all the licenses currently known to the
                |     system.
                | 
                |     Parameters:
                | 
                |         CATSafeArrayVariant
                |             An properly dimensioned array of strings in which the product names
                |             will be stored.
                | 
                |             Example:
                |                 This example determines if the first product in the list of
                |                 known product names is authorized.
                | 
                |                  Dim SystemConfiguration1 As SystemConfiguration
                |                  Set SystemConfiguration1 = CATIA.SystemConfiguration
                |                  ReDim NameArray(SystemConfiguration1.ProductNamesCount)
                |                  SystemConfiguration1.GetProductNames NameArray
                |                  MsgBox "IsProductAuthorized for product " & NameArray(0) & " 
                |                  returns " & SystemConfiguration1.IsProductAuthorized(NameArray(0))

        :param tuple io_product_names:
        :rtype: None
        """
        # return self.system_configuration.GetProductNames()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        vba_function_name = 'get_product_names'
        vba_code = """
        Public Function get_product_names(system_configuration)
            ReDim ioProductNames (system_configuration.ProductCount-1)
            system_configuration.GetProductNames ioProductNames
            get_product_names = ioProductNames
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_product_authorized(self, i_product_name: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsProductAuthorized(CATBSTR iProductName) As boolean
                | 
                |     Returns True if the specified product is authorized, False
                |     otherwise.
                | 
                |     Parameters:
                | 
                |         iProductName
                |             The name of the product to check. 
                |         oAuthorized
                |             A boolean which specifies if the product is
                |             authorized.

        :param str i_product_name:
        :rtype: bool
        """
        return self.system_configuration.IsProductAuthorized(i_product_name)

    def __repr__(self):
        return f'SystemConfiguration(name="{self.name}")'
